1. run the application with default parameter:

```shell
python examples/application/app.py
```

2. run the application with config file

```shell
python examples/application/app.py --config examples/application/cfg.json
```

3. run the application with command line arguments

```shell
python examples/application/app.py -D main.a=1
```